# README

Interact with Ranger json dump from api

## Ranger model

![overview](img/ranger-general.png)

Each policies has a number of similarties with each other but have some specialities (hdf path ...)

![policies](img/ranger-policies.png)
